==> react-web-foundation-0.1.1.tgz: package/es/createElement/createDOMProps/index.js <==
function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import AccessibilityUtil from "../AccessibilityUtil";
import StyleSheet from "../../StyleSheet";

var emptyObject = {};

var resetStyles = StyleSheet.create({
  ariaButton: {
    cursor: "pointer"
  },
  button: {
    appearance: "none",
    backgroundColor: "transparent",
    color: "inherit",
    font: "inherit",
    textAlign: "inherit"
  },
  heading: {
    font: "inherit"
  },
  link: {
    backgroundColor: "transparent",
    color: "inherit",
    textDecorationLine: "none"
  },
  list: {
    listStyle: "none"
  }
});

var createDOMProps = function createDOMProps(component, props) {
  if (!props) {
    props = emptyObject;
  }

  var _props = props,
      accessibilityLabel = _props.accessibilityLabel,
      accessibilityLiveRegion = _props.accessibilityLiveRegion,
      importantForAccessibility = _props.importantForAccessibility,
      providedStyle = _props.style,
      testID = _props.testID,
      accessible = _props.accessible,
      accessibilityRole = _props.accessibilityRole,
      domProps = _objectWithoutProperties(_props, ["accessibilityLabel", "accessibilityLiveRegion", "importantForAccessibility", "style", "testID", "accessible", "accessibilityRole"]);

  var isDisabled = AccessibilityUtil.isDisabled(props);
  var role = accessibilityRole;
  var tabIndex = AccessibilityUtil.propsToTabIndex(props);
  var style = [component === "a" && resetStyles.link, component === "button" && resetStyles.button, role === "heading" && resetStyles.heading, component === "ul" && resetStyles.list, role === "button" && !isDisabled && resetStyles.ariaButton, providedStyle];

  var _StyleSheet$resolve = StyleSheet.resolve(style),
      className = _StyleSheet$resolve.className;

  if (isDisabled) {
    domProps["aria-disabled"] = true;
  }
  if (importantForAccessibility === "no-hide-descendants") {
    domProps["aria-hidden"] = true;
  }
  if (accessibilityLabel && accessibilityLabel.constructor === String) {
    domProps["aria-label"] = accessibilityLabel;
  }
  if (accessibilityLiveRegion && accessibilityLiveRegion.constructor === String) {
    domProps["aria-live"] = accessibilityLiveRegion === "none" ? "off" : accessibilityLiveRegion;
  }
  if (className && className.constructor === String) {
    domProps.className = domProps.className ? domProps.className + " " + className : className;
  }
  if (component === "a" && domProps.target === "_blank") {
    domProps.rel = (domProps.rel || "") + " noopener noreferrer";
  }
  if (role && role.constructor === String && role !== "label") {
    domProps.role = role;
  }
  if (style) {
    domProps.style = style;
  }
  if (tabIndex) {
    domProps.tabIndex = tabIndex;
  }
  if (testID && testID.constructor === String) {
    domProps["data-testid"] = testID;
  }

  return domProps;
};

export default createDOMProps;

==> react-web-foundation-0.1.4.tgz: package/es/createElement/createDOMProps/index.js <==
function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import AccessibilityUtil from "../AccessibilityUtil";
import StyleSheet from "../../StyleSheet";

var emptyObject = {};

var resetStyles = StyleSheet.create({
  ariaButton: {
    cursor: "pointer"
  },
  button: {
    appearance: "none",
    backgroundColor: "transparent",
    color: "inherit",
    font: "inherit",
    textAlign: "inherit"
  },
  heading: {
    font: "inherit"
  },
  link: {
    backgroundColor: "transparent",
    color: "inherit",
    textDecorationLine: "none"
  },
  list: {
    listStyle: "none"
  }
});

var createDOMProps = function createDOMProps(component, props) {
  if (!props) {
    props = emptyObject;
  }

  var _props = props,
      accessibilityLabel = _props.accessibilityLabel,
      accessibilityLiveRegion = _props.accessibilityLiveRegion,
      importantForAccessibility = _props.importantForAccessibility,
      providedStyle = _props.style,
      testID = _props.testID,
      accessible = _props.accessible,
      accessibilityRole = _props.accessibilityRole,
      domProps = _objectWithoutProperties(_props, ["accessibilityLabel", "accessibilityLiveRegion", "importantForAccessibility", "style", "testID", "accessible", "accessibilityRole"]);

  var isDisabled = AccessibilityUtil.isDisabled(props);
  var role = accessibilityRole;
  var tabIndex = AccessibilityUtil.propsToTabIndex(props);
  var styleArray = [component === "a" && resetStyles.link, component === "button" && resetStyles.button, role === "heading" && resetStyles.heading, component === "ul" && resetStyles.list, role === "button" && !isDisabled && resetStyles.ariaButton, providedStyle];

  var _StyleSheet$resolve = StyleSheet.resolve(styleArray),
      className = _StyleSheet$resolve.className,
      style = _StyleSheet$resolve.style;

  if (isDisabled) {
    domProps["aria-disabled"] = true;
  }
  if (importantForAccessibility === "no-hide-descendants") {
    domProps["aria-hidden"] = true;
  }
  if (accessibilityLabel && accessibilityLabel.constructor === String) {
    domProps["aria-label"] = accessibilityLabel;
  }
  if (accessibilityLiveRegion && accessibilityLiveRegion.constructor === String) {
    domProps["aria-live"] = accessibilityLiveRegion === "none" ? "off" : accessibilityLiveRegion;
  }
  if (className && className.constructor === String) {
    domProps.className = domProps.className ? domProps.className + " " + className : className;
  }
  if (component === "a" && domProps.target === "_blank") {
    domProps.rel = (domProps.rel || "") + " noopener noreferrer";
  }
  if (role && role.constructor === String && role !== "label") {
    domProps.role = role;
  }
  if (style) {
    domProps.style = style;
  }
  if (tabIndex) {
    domProps.tabIndex = tabIndex;
  }
  if (testID && testID.constructor === String) {
    domProps["data-testid"] = testID;
  }

  return domProps;
};

export default createDOMProps;
